==> openejb-client-3.1.4-sources.jar: org/apache/openejb/client/ClusterRequest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.openejb.client;

import java.io.ObjectInput;
import java.io.IOException;
import java.io.ObjectOutput;

/**
 * @version $Rev$ $Date$
 */
public class ClusterRequest implements Request {
    private long clusterMetaDataVersion;

    public ClusterRequest() {
    }

    public ClusterRequest(ClusterMetaData clusterMetaData) {
        clusterMetaDataVersion = clusterMetaData.getVersion();
    }

    public byte getRequestType() {
        return RequestMethodConstants.CLUSTER_REQUEST;
    }

    public long getClusterMetaDataVersion() {
        return clusterMetaDataVersion;
    }

    public void readExternal(ObjectInput in) throws IOException, ClassNotFoundException {
        clusterMetaDataVersion = in.readLong();
    }

    public void writeExternal(ObjectOutput out) throws IOException {
        out.writeLong(clusterMetaDataVersion);
    }
}

==> openejb-client-4.5.2-sources.jar: org/apache/openejb/client/ClusterRequest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.openejb.client;

import java.io.ObjectInput;
import java.io.IOException;
import java.io.ObjectOutput;

/**
 * @version $Rev$ $Date$
 */
public class ClusterRequest implements Request {
    private long clusterMetaDataVersion;

    public ClusterRequest() {
    }

    public ClusterRequest(ClusterMetaData clusterMetaData) {
        clusterMetaDataVersion = clusterMetaData.getVersion();
    }

    public RequestType getRequestType() {
        return RequestType.CLUSTER_REQUEST;
    }

    public long getClusterMetaDataVersion() {
        return clusterMetaDataVersion;
    }

    public void readExternal(ObjectInput in) throws IOException, ClassNotFoundException {
        clusterMetaDataVersion = in.readLong();
    }

    public void writeExternal(ObjectOutput out) throws IOException {
        out.writeLong(clusterMetaDataVersion);
    }
}
